prompter

package
v0.48.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 21, 2026 License: AGPL-3.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Manager

type Manager struct{}

Manager represents an entity responsible for managing and registering prompts and their handlers in a server.

func NewManager

func NewManager() *Manager

NewManager creates and returns a new instance of Manager for managing and registering prompts and their handlers.

func (*Manager) HandleDebugHelmRelease

func (m *Manager) HandleDebugHelmRelease(ctx context.Context, request *mcp.GetPromptRequest) (*mcp.GetPromptResult, error)

HandleDebugHelmRelease is the handler function for the debug_flux_helmrelease prompt.

func (*Manager) HandleDebugKustomization

func (m *Manager) HandleDebugKustomization(ctx context.Context, request *mcp.GetPromptRequest) (*mcp.GetPromptResult, error)

HandleDebugKustomization is the handler function for the debug_flux_kustomization prompt.

func (*Manager) NewDebugHelmReleasePrompt

func (m *Manager) NewDebugHelmReleasePrompt() SystemPrompt

NewDebugHelmReleasePrompt creates a prompt for debugging Flux HelmRelease.

func (*Manager) NewDebugKustomizationPrompt

func (m *Manager) NewDebugKustomizationPrompt() SystemPrompt

NewDebugKustomizationPrompt creates a prompt for debugging lux Kustomization.

func (*Manager) PromptSet

func (m *Manager) PromptSet() []SystemPrompt

PromptSet returns a slice of predefined Prompt objects with their associated names, descriptions, and handlers.

func (*Manager) RegisterPrompts

func (m *Manager) RegisterPrompts(server *mcp.Server)

RegisterPrompts registers all prompts in the Manager's PromptSet with the provided server.

type SystemPrompt

type SystemPrompt struct {
	Prompt  *mcp.Prompt
	Handler mcp.PromptHandler
}

Jump to